| Title: | Compound Annual Growth Rate |
|---|---|
| Description: | A time series usually does not have a uniform growth rate. Compound Annual Growth Rate measures the average annual growth over a given period. More details can be found in Bardhan et al. (2022) <DOI:10.18805/ag.D-5418>. |
| Authors: | Debopam Rakshit [aut, cre], Dwaipayan Bardhan [aut] |
| Maintainer: | Debopam Rakshit <[email protected]> |
| License: | GPL-3 |
| Version: | 1.1.1 |
| Built: | 2026-05-21 07:16:02 UTC |
| Source: | https://github.com/cran/CAGR |
Compute CAGR(Compound Annual Growth Rate)
CAGR(data.1, data.n, n)CAGR(data.1, data.n, n)
data.1 |
Data of the first year |
data.n |
Data of the last year |
n |
Number of years |
CAGR and between years values
Bardhan, D., Singh, S.R.K., Raut, A.A.and Athare, T.R. (2022). Livestock in Madhya Pradesh and Chhattisgarh: An Analysis for Some Policy Implications. Agricultural Science Digest. DOI:10.18805/ag.D-5418.
c.cagr<-CAGR(100, 189, 5)c.cagr<-CAGR(100, 189, 5)
Computing first year data
data.first(data.n, r, n)data.first(data.n, r, n)
data.n |
Data of the last year |
r |
CAGR |
n |
Number of years |
First year data and between years values
Bardhan, D., Singh, S.R.K., Raut, A.A.and Athare, T.R. (2022). Livestock in Madhya Pradesh and Chhattisgarh: An Analysis for Some Policy Implications. Agricultural Science Digest. DOI:10.18805/ag.D-5418.
d.first<-data.first(189, 13.57751, 5)d.first<-data.first(189, 13.57751, 5)
Computing last year data
data.last(data.1, r, n)data.last(data.1, r, n)
data.1 |
Data of the first year |
r |
CAGR |
n |
Number of years |
Last year data and between years values
Bardhan, D., Singh, S.R.K., Raut, A.A.and Athare, T.R. (2022). Livestock in Madhya Pradesh and Chhattisgarh: An Analysis for Some Policy Implications. Agricultural Science Digest. DOI:10.18805/ag.D-5418.
d.last<-data.last(100, 13.57751, 5)d.last<-data.last(100, 13.57751, 5)
Estimating the growth rate using the log-linear trend model
LLTM(data)LLTM(data)
data |
Time series data set |
Growth rate and model summary
Bardhan, D., Singh, S.R.K., Raut, A.A.and Athare, T.R. (2022). Livestock in Madhya Pradesh and Chhattisgarh: An Analysis for Some Policy Implications. Agricultural Science Digest. DOI:10.18805/ag.D-5418.
data<- c(100,105,110,118,116,120,130) g.rate <- LLTM(data)data<- c(100,105,110,118,116,120,130) g.rate <- LLTM(data)
Computing number of years
n.years(data.1, data.n, r)n.years(data.1, data.n, r)
data.1 |
Data of the first year |
data.n |
Data of the last year |
r |
CAGR |
Number of years and between years values
Bardhan, D., Singh, S.R.K., Raut, A.A.and Athare, T.R. (2022). Livestock in Madhya Pradesh and Chhattisgarh: An Analysis for Some Policy Implications. Agricultural Science Digest. DOI:10.18805/ag.D-5418.
n.yrs<-n.years(100, 189, 13.57751)n.yrs<-n.years(100, 189, 13.57751)